@@ -3,9 +3,9 @@ Main interface for codebuild service type definitions.
 
 Usage::
 
-    from mypy_boto3.codebuild.type_defs import BuildNotDeletedTypeDef
+    from mypy_boto3.codebuild.type_defs import BuildArtifactsTypeDef
 
-    data: BuildNotDeletedTypeDef = {...}
+    data: BuildArtifactsTypeDef = {...}
 """
 from datetime import datetime
 import sys
@@ -22,56 +22,57 @@ else:
 
 
 __all__ = (
-    "BuildNotDeletedTypeDef",
-    "BatchDeleteBuildsOutputTypeDef",
     "BuildArtifactsTypeDef",
-    "PhaseContextTypeDef",
+    "BuildNotDeletedTypeDef",
     "BuildPhaseTypeDef",
-    "ExportedEnvironmentVariableTypeDef",
+    "BuildTypeDef",
     "CloudWatchLogsConfigTypeDef",
-    "S3LogsConfigTypeDef",
+    "EnvironmentImageTypeDef",
+    "EnvironmentLanguageTypeDef",
+    "EnvironmentPlatformTypeDef",
+    "EnvironmentVariableTypeDef",
+    "ExportedEnvironmentVariableTypeDef",
+    "GitSubmodulesConfigTypeDef",
+    "LogsConfigTypeDef",
     "LogsLocationTypeDef",
     "NetworkInterfaceTypeDef",
-    "ProjectCacheTypeDef",
-    "EnvironmentVariableTypeDef",
-    "RegistryCredentialTypeDef",
-    "ProjectEnvironmentTypeDef",
-    "ProjectFileSystemLocationTypeDef",
-    "GitSubmodulesConfigTypeDef",
-    "SourceAuthTypeDef",
-    "ProjectSourceTypeDef",
-    "ProjectSourceVersionTypeDef",
-    "VpcConfigTypeDef",
-    "BuildTypeDef",
-    "BatchGetBuildsOutputTypeDef",
-    "LogsConfigTypeDef",
+    "PhaseContextTypeDef",
     "ProjectArtifactsTypeDef",
     "ProjectBadgeTypeDef",
-    "TagTypeDef",
-    "WebhookFilterTypeDef",
-    "WebhookTypeDef",
+    "ProjectCacheTypeDef",
+    "ProjectEnvironmentTypeDef",
+    "ProjectFileSystemLocationTypeDef",
+    "ProjectSourceTypeDef",
+    "ProjectSourceVersionTypeDef",
     "ProjectTypeDef",
-    "BatchGetProjectsOutputTypeDef",
-    "S3ReportExportConfigTypeDef",
+    "RegistryCredentialTypeDef",
     "ReportExportConfigTypeDef",
     "ReportGroupTypeDef",
-    "BatchGetReportGroupsOutputTypeDef",
-    "TestReportSummaryTypeDef",
     "ReportTypeDef",
+    "S3LogsConfigTypeDef",
+    "S3ReportExportConfigTypeDef",
+    "SourceAuthTypeDef",
+    "SourceCredentialsInfoTypeDef",
+    "TagTypeDef",
+    "TestCaseTypeDef",
+    "TestReportSummaryTypeDef",
+    "VpcConfigTypeDef",
+    "WebhookFilterTypeDef",
+    "WebhookTypeDef",
+    "BatchDeleteBuildsOutputTypeDef",
+    "BatchGetBuildsOutputTypeDef",
+    "BatchGetProjectsOutputTypeDef",
+    "BatchGetReportGroupsOutputTypeDef",
     "BatchGetReportsOutputTypeDef",
     "CreateProjectOutputTypeDef",
     "CreateReportGroupOutputTypeDef",
     "CreateWebhookOutputTypeDef",
     "DeleteSourceCredentialsOutputTypeDef",
-    "TestCaseTypeDef",
     "DescribeTestCasesOutputTypeDef",
     "GetResourcePolicyOutputTypeDef",
     "ImportSourceCredentialsOutputTypeDef",
     "ListBuildsForProjectOutputTypeDef",
     "ListBuildsOutputTypeDef",
-    "EnvironmentImageTypeDef",
-    "EnvironmentLanguageTypeDef",
-    "EnvironmentPlatformTypeDef",
     "ListCuratedEnvironmentImagesOutputTypeDef",
     "ListProjectsOutputTypeDef",
     "ListReportGroupsOutputTypeDef",
@@ -79,7 +80,6 @@ __all__ = (
     "ListReportsOutputTypeDef",
     "ListSharedProjectsOutputTypeDef",
     "ListSharedReportGroupsOutputTypeDef",
-    "SourceCredentialsInfoTypeDef",
     "ListSourceCredentialsOutputTypeDef",
     "PaginatorConfigTypeDef",
     "PutResourcePolicyOutputTypeDef",
@@ -92,16 +92,6 @@ __all__ = (
     "UpdateWebhookOutputTypeDef",
 )
 
-BuildNotDeletedTypeDef = TypedDict(
-    "BuildNotDeletedTypeDef", {"id": str, "statusCode": str}, total=False
-)
-
-BatchDeleteBuildsOutputTypeDef = TypedDict(
-    "BatchDeleteBuildsOutputTypeDef",
-    {"buildsDeleted": List[str], "buildsNotDeleted": List[BuildNotDeletedTypeDef]},
-    total=False,
-)
-
 BuildArtifactsTypeDef = TypedDict(
     "BuildArtifactsTypeDef",
     {
@@ -115,8 +105,8 @@ BuildArtifactsTypeDef = TypedDict(
     total=False,
 )
 
-PhaseContextTypeDef = TypedDict(
-    "PhaseContextTypeDef", {"statusCode": str, "message": str}, total=False
+BuildNotDeletedTypeDef = TypedDict(
+    "BuildNotDeletedTypeDef", {"id": str, "statusCode": str}, total=False
 )
 
 BuildPhaseTypeDef = TypedDict(
@@ -141,200 +131,11 @@ BuildPhaseTypeDef = TypedDict(
         "startTime": datetime,
         "endTime": datetime,
         "durationInSeconds": int,
-        "contexts": List[PhaseContextTypeDef],
+        "contexts": List["PhaseContextTypeDef"],
     },
     total=False,
 )
 
-ExportedEnvironmentVariableTypeDef = TypedDict(
-    "ExportedEnvironmentVariableTypeDef", {"name": str, "value": str}, total=False
-)
-
-_RequiredCloudWatchLogsConfigTypeDef = TypedDict(
-    "_RequiredCloudWatchLogsConfigTypeDef", {"status": Literal["ENABLED", "DISABLED"]}
-)
-_OptionalCloudWatchLogsConfigTypeDef = TypedDict(
-    "_OptionalCloudWatchLogsConfigTypeDef", {"groupName": str, "streamName": str}, total=False
-)
-
-
-class CloudWatchLogsConfigTypeDef(
-    _RequiredCloudWatchLogsConfigTypeDef, _OptionalCloudWatchLogsConfigTypeDef
-):
-    pass
-
-
-_RequiredS3LogsConfigTypeDef = TypedDict(
-    "_RequiredS3LogsConfigTypeDef", {"status": Literal["ENABLED", "DISABLED"]}
-)
-_OptionalS3LogsConfigTypeDef = TypedDict(
-    "_OptionalS3LogsConfigTypeDef", {"location": str, "encryptionDisabled": bool}, total=False
-)
-
-
-class S3LogsConfigTypeDef(_RequiredS3LogsConfigTypeDef, _OptionalS3LogsConfigTypeDef):
-    pass
-
-
-LogsLocationTypeDef = TypedDict(
-    "LogsLocationTypeDef",
-    {
-        "groupName": str,
-        "streamName": str,
-        "deepLink": str,
-        "s3DeepLink": str,
-        "cloudWatchLogsArn": str,
-        "s3LogsArn": str,
-        "cloudWatchLogs": CloudWatchLogsConfigTypeDef,
-        "s3Logs": S3LogsConfigTypeDef,
-    },
-    total=False,
-)
-
-NetworkInterfaceTypeDef = TypedDict(
-    "NetworkInterfaceTypeDef", {"subnetId": str, "networkInterfaceId": str}, total=False
-)
-
-_RequiredProjectCacheTypeDef = TypedDict(
-    "_RequiredProjectCacheTypeDef", {"type": Literal["NO_CACHE", "S3", "LOCAL"]}
-)
-_OptionalProjectCacheTypeDef = TypedDict(
-    "_OptionalProjectCacheTypeDef",
-    {
-        "location": str,
-        "modes": List[
-            Literal["LOCAL_DOCKER_LAYER_CACHE", "LOCAL_SOURCE_CACHE", "LOCAL_CUSTOM_CACHE"]
-        ],
-    },
-    total=False,
-)
-
-
-class ProjectCacheTypeDef(_RequiredProjectCacheTypeDef, _OptionalProjectCacheTypeDef):
-    pass
-
-
-_RequiredEnvironmentVariableTypeDef = TypedDict(
-    "_RequiredEnvironmentVariableTypeDef", {"name": str, "value": str}
-)
-_OptionalEnvironmentVariableTypeDef = TypedDict(
-    "_OptionalEnvironmentVariableTypeDef",
-    {"type": Literal["PLAINTEXT", "PARAMETER_STORE", "SECRETS_MANAGER"]},
-    total=False,
-)
-
-
-class EnvironmentVariableTypeDef(
-    _RequiredEnvironmentVariableTypeDef, _OptionalEnvironmentVariableTypeDef
-):
-    pass
-
-
-RegistryCredentialTypeDef = TypedDict(
-    "RegistryCredentialTypeDef",
-    {"credential": str, "credentialProvider": Literal["SECRETS_MANAGER"]},
-)
-
-_RequiredProjectEnvironmentTypeDef = TypedDict(
-    "_RequiredProjectEnvironmentTypeDef",
-    {
-        "type": Literal[
-            "WINDOWS_CONTAINER", "LINUX_CONTAINER", "LINUX_GPU_CONTAINER", "ARM_CONTAINER"
-        ],
-        "image": str,
-        "computeType": Literal[
-            "BUILD_GENERAL1_SMALL",
-            "BUILD_GENERAL1_MEDIUM",
-            "BUILD_GENERAL1_LARGE",
-            "BUILD_GENERAL1_2XLARGE",
-        ],
-    },
-)
-_OptionalProjectEnvironmentTypeDef = TypedDict(
-    "_OptionalProjectEnvironmentTypeDef",
-    {
-        "environmentVariables": List[EnvironmentVariableTypeDef],
-        "privilegedMode": bool,
-        "certificate": str,
-        "registryCredential": RegistryCredentialTypeDef,
-        "imagePullCredentialsType": Literal["CODEBUILD", "SERVICE_ROLE"],
-    },
-    total=False,
-)
-
-
-class ProjectEnvironmentTypeDef(
-    _RequiredProjectEnvironmentTypeDef, _OptionalProjectEnvironmentTypeDef
-):
-    pass
-
-
-ProjectFileSystemLocationTypeDef = TypedDict(
-    "ProjectFileSystemLocationTypeDef",
-    {
-        "type": Literal["EFS"],
-        "location": str,
-        "mountPoint": str,
-        "identifier": str,
-        "mountOptions": str,
-    },
-    total=False,
-)
-
-GitSubmodulesConfigTypeDef = TypedDict("GitSubmodulesConfigTypeDef", {"fetchSubmodules": bool})
-
-_RequiredSourceAuthTypeDef = TypedDict("_RequiredSourceAuthTypeDef", {"type": Literal["OAUTH"]})
-_OptionalSourceAuthTypeDef = TypedDict("_OptionalSourceAuthTypeDef", {"resource": str}, total=False)
-
-
-class SourceAuthTypeDef(_RequiredSourceAuthTypeDef, _OptionalSourceAuthTypeDef):
-    pass
-
-
-_RequiredProjectSourceTypeDef = TypedDict(
-    "_RequiredProjectSourceTypeDef",
-    {
-        "type": Literal[
-            "CODECOMMIT",
-            "CODEPIPELINE",
-            "GITHUB",
-            "S3",
-            "BITBUCKET",
-            "GITHUB_ENTERPRISE",
-            "NO_SOURCE",
-        ]
-    },
-)
-_OptionalProjectSourceTypeDef = TypedDict(
-    "_OptionalProjectSourceTypeDef",
-    {
-        "location": str,
-        "gitCloneDepth": int,
-        "gitSubmodulesConfig": GitSubmodulesConfigTypeDef,
-        "buildspec": str,
-        "auth": SourceAuthTypeDef,
-        "reportBuildStatus": bool,
-        "insecureSsl": bool,
-        "sourceIdentifier": str,
-    },
-    total=False,
-)
-
-
-class ProjectSourceTypeDef(_RequiredProjectSourceTypeDef, _OptionalProjectSourceTypeDef):
-    pass
-
-
-ProjectSourceVersionTypeDef = TypedDict(
-    "ProjectSourceVersionTypeDef", {"sourceIdentifier": str, "sourceVersion": str}
-)
-
-VpcConfigTypeDef = TypedDict(
-    "VpcConfigTypeDef",
-    {"vpcId": str, "subnets": List[str], "securityGroupIds": List[str]},
-    total=False,
-)
-
 BuildTypeDef = TypedDict(
     "BuildTypeDef",
     {
@@ -350,42 +151,128 @@ BuildTypeDef = TypedDict(
         "sourceVersion": str,
         "resolvedSourceVersion": str,
         "projectName": str,
-        "phases": List[BuildPhaseTypeDef],
-        "source": ProjectSourceTypeDef,
-        "secondarySources": List[ProjectSourceTypeDef],
-        "secondarySourceVersions": List[ProjectSourceVersionTypeDef],
-        "artifacts": BuildArtifactsTypeDef,
-        "secondaryArtifacts": List[BuildArtifactsTypeDef],
-        "cache": ProjectCacheTypeDef,
-        "environment": ProjectEnvironmentTypeDef,
+        "phases": List["BuildPhaseTypeDef"],
+        "source": "ProjectSourceTypeDef",
+        "secondarySources": List["ProjectSourceTypeDef"],
+        "secondarySourceVersions": List["ProjectSourceVersionTypeDef"],
+        "artifacts": "BuildArtifactsTypeDef",
+        "secondaryArtifacts": List["BuildArtifactsTypeDef"],
+        "cache": "ProjectCacheTypeDef",
+        "environment": "ProjectEnvironmentTypeDef",
         "serviceRole": str,
-        "logs": LogsLocationTypeDef,
+        "logs": "LogsLocationTypeDef",
         "timeoutInMinutes": int,
         "queuedTimeoutInMinutes": int,
         "buildComplete": bool,
         "initiator": str,
-        "vpcConfig": VpcConfigTypeDef,
-        "networkInterface": NetworkInterfaceTypeDef,
+        "vpcConfig": "VpcConfigTypeDef",
+        "networkInterface": "NetworkInterfaceTypeDef",
         "encryptionKey": str,
-        "exportedEnvironmentVariables": List[ExportedEnvironmentVariableTypeDef],
+        "exportedEnvironmentVariables": List["ExportedEnvironmentVariableTypeDef"],
         "reportArns": List[str],
-        "fileSystemLocations": List[ProjectFileSystemLocationTypeDef],
+        "fileSystemLocations": List["ProjectFileSystemLocationTypeDef"],
     },
     total=False,
 )
 
-BatchGetBuildsOutputTypeDef = TypedDict(
-    "BatchGetBuildsOutputTypeDef",
-    {"builds": List[BuildTypeDef], "buildsNotFound": List[str]},
+_RequiredCloudWatchLogsConfigTypeDef = TypedDict(
+    "_RequiredCloudWatchLogsConfigTypeDef", {"status": Literal["ENABLED", "DISABLED"]}
+)
+_OptionalCloudWatchLogsConfigTypeDef = TypedDict(
+    "_OptionalCloudWatchLogsConfigTypeDef", {"groupName": str, "streamName": str}, total=False
+)
+
+
+class CloudWatchLogsConfigTypeDef(
+    _RequiredCloudWatchLogsConfigTypeDef, _OptionalCloudWatchLogsConfigTypeDef
+):
+    pass
+
+
+EnvironmentImageTypeDef = TypedDict(
+    "EnvironmentImageTypeDef", {"name": str, "description": str, "versions": List[str]}, total=False
+)
+
+EnvironmentLanguageTypeDef = TypedDict(
+    "EnvironmentLanguageTypeDef",
+    {
+        "language": Literal[
+            "JAVA",
+            "PYTHON",
+            "NODE_JS",
+            "RUBY",
+            "GOLANG",
+            "DOCKER",
+            "ANDROID",
+            "DOTNET",
+            "BASE",
+            "PHP",
+        ],
+        "images": List["EnvironmentImageTypeDef"],
+    },
     total=False,
 )
 
+EnvironmentPlatformTypeDef = TypedDict(
+    "EnvironmentPlatformTypeDef",
+    {
+        "platform": Literal["DEBIAN", "AMAZON_LINUX", "UBUNTU", "WINDOWS_SERVER"],
+        "languages": List["EnvironmentLanguageTypeDef"],
+    },
+    total=False,
+)
+
+_RequiredEnvironmentVariableTypeDef = TypedDict(
+    "_RequiredEnvironmentVariableTypeDef", {"name": str, "value": str}
+)
+_OptionalEnvironmentVariableTypeDef = TypedDict(
+    "_OptionalEnvironmentVariableTypeDef",
+    {"type": Literal["PLAINTEXT", "PARAMETER_STORE", "SECRETS_MANAGER"]},
+    total=False,
+)
+
+
+class EnvironmentVariableTypeDef(
+    _RequiredEnvironmentVariableTypeDef, _OptionalEnvironmentVariableTypeDef
+):
+    pass
+
+
+ExportedEnvironmentVariableTypeDef = TypedDict(
+    "ExportedEnvironmentVariableTypeDef", {"name": str, "value": str}, total=False
+)
+
+GitSubmodulesConfigTypeDef = TypedDict("GitSubmodulesConfigTypeDef", {"fetchSubmodules": bool})
+
 LogsConfigTypeDef = TypedDict(
     "LogsConfigTypeDef",
-    {"cloudWatchLogs": CloudWatchLogsConfigTypeDef, "s3Logs": S3LogsConfigTypeDef},
+    {"cloudWatchLogs": "CloudWatchLogsConfigTypeDef", "s3Logs": "S3LogsConfigTypeDef"},
     total=False,
 )
 
+LogsLocationTypeDef = TypedDict(
+    "LogsLocationTypeDef",
+    {
+        "groupName": str,
+        "streamName": str,
+        "deepLink": str,
+        "s3DeepLink": str,
+        "cloudWatchLogsArn": str,
+        "s3LogsArn": str,
+        "cloudWatchLogs": "CloudWatchLogsConfigTypeDef",
+        "s3Logs": "S3LogsConfigTypeDef",
+    },
+    total=False,
+)
+
+NetworkInterfaceTypeDef = TypedDict(
+    "NetworkInterfaceTypeDef", {"subnetId": str, "networkInterfaceId": str}, total=False
+)
+
+PhaseContextTypeDef = TypedDict(
+    "PhaseContextTypeDef", {"statusCode": str, "message": str}, total=False
+)
+
 _RequiredProjectArtifactsTypeDef = TypedDict(
     "_RequiredProjectArtifactsTypeDef", {"type": Literal["CODEPIPELINE", "S3", "NO_ARTIFACTS"]}
 )
@@ -413,8 +300,255 @@ ProjectBadgeTypeDef = TypedDict(
     "ProjectBadgeTypeDef", {"badgeEnabled": bool, "badgeRequestUrl": str}, total=False
 )
 
+_RequiredProjectCacheTypeDef = TypedDict(
+    "_RequiredProjectCacheTypeDef", {"type": Literal["NO_CACHE", "S3", "LOCAL"]}
+)
+_OptionalProjectCacheTypeDef = TypedDict(
+    "_OptionalProjectCacheTypeDef",
+    {
+        "location": str,
+        "modes": List[
+            Literal["LOCAL_DOCKER_LAYER_CACHE", "LOCAL_SOURCE_CACHE", "LOCAL_CUSTOM_CACHE"]
+        ],
+    },
+    total=False,
+)
+
+
+class ProjectCacheTypeDef(_RequiredProjectCacheTypeDef, _OptionalProjectCacheTypeDef):
+    pass
+
+
+_RequiredProjectEnvironmentTypeDef = TypedDict(
+    "_RequiredProjectEnvironmentTypeDef",
+    {
+        "type": Literal[
+            "WINDOWS_CONTAINER", "LINUX_CONTAINER", "LINUX_GPU_CONTAINER", "ARM_CONTAINER"
+        ],
+        "image": str,
+        "computeType": Literal[
+            "BUILD_GENERAL1_SMALL",
+            "BUILD_GENERAL1_MEDIUM",
+            "BUILD_GENERAL1_LARGE",
+            "BUILD_GENERAL1_2XLARGE",
+        ],
+    },
+)
+_OptionalProjectEnvironmentTypeDef = TypedDict(
+    "_OptionalProjectEnvironmentTypeDef",
+    {
+        "environmentVariables": List["EnvironmentVariableTypeDef"],
+        "privilegedMode": bool,
+        "certificate": str,
+        "registryCredential": "RegistryCredentialTypeDef",
+        "imagePullCredentialsType": Literal["CODEBUILD", "SERVICE_ROLE"],
+    },
+    total=False,
+)
+
+
+class ProjectEnvironmentTypeDef(
+    _RequiredProjectEnvironmentTypeDef, _OptionalProjectEnvironmentTypeDef
+):
+    pass
+
+
+ProjectFileSystemLocationTypeDef = TypedDict(
+    "ProjectFileSystemLocationTypeDef",
+    {
+        "type": Literal["EFS"],
+        "location": str,
+        "mountPoint": str,
+        "identifier": str,
+        "mountOptions": str,
+    },
+    total=False,
+)
+
+_RequiredProjectSourceTypeDef = TypedDict(
+    "_RequiredProjectSourceTypeDef",
+    {
+        "type": Literal[
+            "CODECOMMIT",
+            "CODEPIPELINE",
+            "GITHUB",
+            "S3",
+            "BITBUCKET",
+            "GITHUB_ENTERPRISE",
+            "NO_SOURCE",
+        ]
+    },
+)
+_OptionalProjectSourceTypeDef = TypedDict(
+    "_OptionalProjectSourceTypeDef",
+    {
+        "location": str,
+        "gitCloneDepth": int,
+        "gitSubmodulesConfig": "GitSubmodulesConfigTypeDef",
+        "buildspec": str,
+        "auth": "SourceAuthTypeDef",
+        "reportBuildStatus": bool,
+        "insecureSsl": bool,
+        "sourceIdentifier": str,
+    },
+    total=False,
+)
+
+
+class ProjectSourceTypeDef(_RequiredProjectSourceTypeDef, _OptionalProjectSourceTypeDef):
+    pass
+
+
+ProjectSourceVersionTypeDef = TypedDict(
+    "ProjectSourceVersionTypeDef", {"sourceIdentifier": str, "sourceVersion": str}
+)
+
+ProjectTypeDef = TypedDict(
+    "ProjectTypeDef",
+    {
+        "name": str,
+        "arn": str,
+        "description": str,
+        "source": "ProjectSourceTypeDef",
+        "secondarySources": List["ProjectSourceTypeDef"],
+        "sourceVersion": str,
+        "secondarySourceVersions": List["ProjectSourceVersionTypeDef"],
+        "artifacts": "ProjectArtifactsTypeDef",
+        "secondaryArtifacts": List["ProjectArtifactsTypeDef"],
+        "cache": "ProjectCacheTypeDef",
+        "environment": "ProjectEnvironmentTypeDef",
+        "serviceRole": str,
+        "timeoutInMinutes": int,
+        "queuedTimeoutInMinutes": int,
+        "encryptionKey": str,
+        "tags": List["TagTypeDef"],
+        "created": datetime,
+        "lastModified": datetime,
+        "webhook": "WebhookTypeDef",
+        "vpcConfig": "VpcConfigTypeDef",
+        "badge": "ProjectBadgeTypeDef",
+        "logsConfig": "LogsConfigTypeDef",
+        "fileSystemLocations": List["ProjectFileSystemLocationTypeDef"],
+    },
+    total=False,
+)
+
+RegistryCredentialTypeDef = TypedDict(
+    "RegistryCredentialTypeDef",
+    {"credential": str, "credentialProvider": Literal["SECRETS_MANAGER"]},
+)
+
+ReportExportConfigTypeDef = TypedDict(
+    "ReportExportConfigTypeDef",
+    {
+        "exportConfigType": Literal["S3", "NO_EXPORT"],
+        "s3Destination": "S3ReportExportConfigTypeDef",
+    },
+    total=False,
+)
+
+ReportGroupTypeDef = TypedDict(
+    "ReportGroupTypeDef",
+    {
+        "arn": str,
+        "name": str,
+        "type": Literal["TEST"],
+        "exportConfig": "ReportExportConfigTypeDef",
+        "created": datetime,
+        "lastModified": datetime,
+        "tags": List["TagTypeDef"],
+    },
+    total=False,
+)
+
+ReportTypeDef = TypedDict(
+    "ReportTypeDef",
+    {
+        "arn": str,
+        "type": Literal["TEST"],
+        "name": str,
+        "reportGroupArn": str,
+        "executionId": str,
+        "status": Literal["GENERATING", "SUCCEEDED", "FAILED", "INCOMPLETE", "DELETING"],
+        "created": datetime,
+        "expired": datetime,
+        "exportConfig": "ReportExportConfigTypeDef",
+        "truncated": bool,
+        "testSummary": "TestReportSummaryTypeDef",
+    },
+    total=False,
+)
+
+_RequiredS3LogsConfigTypeDef = TypedDict(
+    "_RequiredS3LogsConfigTypeDef", {"status": Literal["ENABLED", "DISABLED"]}
+)
+_OptionalS3LogsConfigTypeDef = TypedDict(
+    "_OptionalS3LogsConfigTypeDef", {"location": str, "encryptionDisabled": bool}, total=False
+)
+
+
+class S3LogsConfigTypeDef(_RequiredS3LogsConfigTypeDef, _OptionalS3LogsConfigTypeDef):
+    pass
+
+
+S3ReportExportConfigTypeDef = TypedDict(
+    "S3ReportExportConfigTypeDef",
+    {
+        "bucket": str,
+        "path": str,
+        "packaging": Literal["ZIP", "NONE"],
+        "encryptionKey": str,
+        "encryptionDisabled": bool,
+    },
+    total=False,
+)
+
+_RequiredSourceAuthTypeDef = TypedDict("_RequiredSourceAuthTypeDef", {"type": Literal["OAUTH"]})
+_OptionalSourceAuthTypeDef = TypedDict("_OptionalSourceAuthTypeDef", {"resource": str}, total=False)
+
+
+class SourceAuthTypeDef(_RequiredSourceAuthTypeDef, _OptionalSourceAuthTypeDef):
+    pass
+
+
+SourceCredentialsInfoTypeDef = TypedDict(
+    "SourceCredentialsInfoTypeDef",
+    {
+        "arn": str,
+        "serverType": Literal["GITHUB", "BITBUCKET", "GITHUB_ENTERPRISE"],
+        "authType": Literal["OAUTH", "BASIC_AUTH", "PERSONAL_ACCESS_TOKEN"],
+    },
+    total=False,
+)
+
 TagTypeDef = TypedDict("TagTypeDef", {"key": str, "value": str}, total=False)
 
+TestCaseTypeDef = TypedDict(
+    "TestCaseTypeDef",
+    {
+        "reportArn": str,
+        "testRawDataPath": str,
+        "prefix": str,
+        "name": str,
+        "status": str,
+        "durationInNanoSeconds": int,
+        "message": str,
+        "expired": datetime,
+    },
+    total=False,
+)
+
+TestReportSummaryTypeDef = TypedDict(
+    "TestReportSummaryTypeDef",
+    {"total": int, "statusCounts": Dict[str, int], "durationInNanoSeconds": int},
+)
+
+VpcConfigTypeDef = TypedDict(
+    "VpcConfigTypeDef",
+    {"vpcId": str, "subnets": List[str], "securityGroupIds": List[str]},
+    total=False,
+)
+
 _RequiredWebhookFilterTypeDef = TypedDict(
     "_RequiredWebhookFilterTypeDef",
     {
@@ -440,149 +574,61 @@ WebhookTypeDef = TypedDict(
         "payloadUrl": str,
         "secret": str,
         "branchFilter": str,
-        "filterGroups": List[List[WebhookFilterTypeDef]],
+        "filterGroups": List[List["WebhookFilterTypeDef"]],
         "lastModifiedSecret": datetime,
     },
     total=False,
 )
 
-ProjectTypeDef = TypedDict(
-    "ProjectTypeDef",
-    {
-        "name": str,
-        "arn": str,
-        "description": str,
-        "source": ProjectSourceTypeDef,
-        "secondarySources": List[ProjectSourceTypeDef],
-        "sourceVersion": str,
-        "secondarySourceVersions": List[ProjectSourceVersionTypeDef],
-        "artifacts": ProjectArtifactsTypeDef,
-        "secondaryArtifacts": List[ProjectArtifactsTypeDef],
-        "cache": ProjectCacheTypeDef,
-        "environment": ProjectEnvironmentTypeDef,
-        "serviceRole": str,
-        "timeoutInMinutes": int,
-        "queuedTimeoutInMinutes": int,
-        "encryptionKey": str,
-        "tags": List[TagTypeDef],
-        "created": datetime,
-        "lastModified": datetime,
-        "webhook": WebhookTypeDef,
-        "vpcConfig": VpcConfigTypeDef,
-        "badge": ProjectBadgeTypeDef,
-        "logsConfig": LogsConfigTypeDef,
-        "fileSystemLocations": List[ProjectFileSystemLocationTypeDef],
-    },
+BatchDeleteBuildsOutputTypeDef = TypedDict(
+    "BatchDeleteBuildsOutputTypeDef",
+    {"buildsDeleted": List[str], "buildsNotDeleted": List["BuildNotDeletedTypeDef"]},
+    total=False,
+)
+
+BatchGetBuildsOutputTypeDef = TypedDict(
+    "BatchGetBuildsOutputTypeDef",
+    {"builds": List["BuildTypeDef"], "buildsNotFound": List[str]},
     total=False,
 )
 
 BatchGetProjectsOutputTypeDef = TypedDict(
     "BatchGetProjectsOutputTypeDef",
-    {"projects": List[ProjectTypeDef], "projectsNotFound": List[str]},
-    total=False,
-)
-
-S3ReportExportConfigTypeDef = TypedDict(
-    "S3ReportExportConfigTypeDef",
-    {
-        "bucket": str,
-        "path": str,
-        "packaging": Literal["ZIP", "NONE"],
-        "encryptionKey": str,
-        "encryptionDisabled": bool,
-    },
-    total=False,
-)
-
-ReportExportConfigTypeDef = TypedDict(
-    "ReportExportConfigTypeDef",
-    {"exportConfigType": Literal["S3", "NO_EXPORT"], "s3Destination": S3ReportExportConfigTypeDef},
-    total=False,
-)
-
-ReportGroupTypeDef = TypedDict(
-    "ReportGroupTypeDef",
-    {
-        "arn": str,
-        "name": str,
-        "type": Literal["TEST"],
-        "exportConfig": ReportExportConfigTypeDef,
-        "created": datetime,
-        "lastModified": datetime,
-        "tags": List[TagTypeDef],
-    },
+    {"projects": List["ProjectTypeDef"], "projectsNotFound": List[str]},
     total=False,
 )
 
 BatchGetReportGroupsOutputTypeDef = TypedDict(
     "BatchGetReportGroupsOutputTypeDef",
-    {"reportGroups": List[ReportGroupTypeDef], "reportGroupsNotFound": List[str]},
-    total=False,
-)
-
-TestReportSummaryTypeDef = TypedDict(
-    "TestReportSummaryTypeDef",
-    {"total": int, "statusCounts": Dict[str, int], "durationInNanoSeconds": int},
-)
-
-ReportTypeDef = TypedDict(
-    "ReportTypeDef",
-    {
-        "arn": str,
-        "type": Literal["TEST"],
-        "name": str,
-        "reportGroupArn": str,
-        "executionId": str,
-        "status": Literal["GENERATING", "SUCCEEDED", "FAILED", "INCOMPLETE", "DELETING"],
-        "created": datetime,
-        "expired": datetime,
-        "exportConfig": ReportExportConfigTypeDef,
-        "truncated": bool,
-        "testSummary": TestReportSummaryTypeDef,
-    },
+    {"reportGroups": List["ReportGroupTypeDef"], "reportGroupsNotFound": List[str]},
     total=False,
 )
 
 BatchGetReportsOutputTypeDef = TypedDict(
     "BatchGetReportsOutputTypeDef",
-    {"reports": List[ReportTypeDef], "reportsNotFound": List[str]},
+    {"reports": List["ReportTypeDef"], "reportsNotFound": List[str]},
     total=False,
 )
 
 CreateProjectOutputTypeDef = TypedDict(
-    "CreateProjectOutputTypeDef", {"project": ProjectTypeDef}, total=False
+    "CreateProjectOutputTypeDef", {"project": "ProjectTypeDef"}, total=False
 )
 
 CreateReportGroupOutputTypeDef = TypedDict(
-    "CreateReportGroupOutputTypeDef", {"reportGroup": ReportGroupTypeDef}, total=False
+    "CreateReportGroupOutputTypeDef", {"reportGroup": "ReportGroupTypeDef"}, total=False
 )
 
 CreateWebhookOutputTypeDef = TypedDict(
-    "CreateWebhookOutputTypeDef", {"webhook": WebhookTypeDef}, total=False
+    "CreateWebhookOutputTypeDef", {"webhook": "WebhookTypeDef"}, total=False
 )
 
 DeleteSourceCredentialsOutputTypeDef = TypedDict(
     "DeleteSourceCredentialsOutputTypeDef", {"arn": str}, total=False
 )
 
-TestCaseTypeDef = TypedDict(
-    "TestCaseTypeDef",
-    {
-        "reportArn": str,
-        "testRawDataPath": str,
-        "prefix": str,
-        "name": str,
-        "status": str,
-        "durationInNanoSeconds": int,
-        "message": str,
-        "expired": datetime,
-    },
-    total=False,
-)
-
 DescribeTestCasesOutputTypeDef = TypedDict(
     "DescribeTestCasesOutputTypeDef",
-    {"nextToken": str, "testCases": List[TestCaseTypeDef]},
+    {"nextToken": str, "testCases": List["TestCaseTypeDef"]},
     total=False,
 )
 
@@ -602,42 +648,9 @@ ListBuildsOutputTypeDef = TypedDict(
     "ListBuildsOutputTypeDef", {"ids": List[str], "nextToken": str}, total=False
 )
 
-EnvironmentImageTypeDef = TypedDict(
-    "EnvironmentImageTypeDef", {"name": str, "description": str, "versions": List[str]}, total=False
-)
-
-EnvironmentLanguageTypeDef = TypedDict(
-    "EnvironmentLanguageTypeDef",
-    {
-        "language": Literal[
-            "JAVA",
-            "PYTHON",
-            "NODE_JS",
-            "RUBY",
-            "GOLANG",
-            "DOCKER",
-            "ANDROID",
-            "DOTNET",
-            "BASE",
-            "PHP",
-        ],
-        "images": List[EnvironmentImageTypeDef],
-    },
-    total=False,
-)
-
-EnvironmentPlatformTypeDef = TypedDict(
-    "EnvironmentPlatformTypeDef",
-    {
-        "platform": Literal["DEBIAN", "AMAZON_LINUX", "UBUNTU", "WINDOWS_SERVER"],
-        "languages": List[EnvironmentLanguageTypeDef],
-    },
-    total=False,
-)
-
 ListCuratedEnvironmentImagesOutputTypeDef = TypedDict(
     "ListCuratedEnvironmentImagesOutputTypeDef",
-    {"platforms": List[EnvironmentPlatformTypeDef]},
+    {"platforms": List["EnvironmentPlatformTypeDef"]},
     total=False,
 )
 
@@ -667,19 +680,9 @@ ListSharedReportGroupsOutputTypeDef = TypedDict(
     total=False,
 )
 
-SourceCredentialsInfoTypeDef = TypedDict(
-    "SourceCredentialsInfoTypeDef",
-    {
-        "arn": str,
-        "serverType": Literal["GITHUB", "BITBUCKET", "GITHUB_ENTERPRISE"],
-        "authType": Literal["OAUTH", "BASIC_AUTH", "PERSONAL_ACCESS_TOKEN"],
-    },
-    total=False,
-)
-
 ListSourceCredentialsOutputTypeDef = TypedDict(
     "ListSourceCredentialsOutputTypeDef",
-    {"sourceCredentialsInfos": List[SourceCredentialsInfoTypeDef]},
+    {"sourceCredentialsInfos": List["SourceCredentialsInfoTypeDef"]},
     total=False,
 )
 
@@ -697,20 +700,22 @@ ReportFilterTypeDef = TypedDict(
     total=False,
 )
 
-StartBuildOutputTypeDef = TypedDict("StartBuildOutputTypeDef", {"build": BuildTypeDef}, total=False)
+StartBuildOutputTypeDef = TypedDict(
+    "StartBuildOutputTypeDef", {"build": "BuildTypeDef"}, total=False
+)
 
-StopBuildOutputTypeDef = TypedDict("StopBuildOutputTypeDef", {"build": BuildTypeDef}, total=False)
+StopBuildOutputTypeDef = TypedDict("StopBuildOutputTypeDef", {"build": "BuildTypeDef"}, total=False)
 
 TestCaseFilterTypeDef = TypedDict("TestCaseFilterTypeDef", {"status": str}, total=False)
 
 UpdateProjectOutputTypeDef = TypedDict(
-    "UpdateProjectOutputTypeDef", {"project": ProjectTypeDef}, total=False
+    "UpdateProjectOutputTypeDef", {"project": "ProjectTypeDef"}, total=False
 )
 
 UpdateReportGroupOutputTypeDef = TypedDict(
-    "UpdateReportGroupOutputTypeDef", {"reportGroup": ReportGroupTypeDef}, total=False
+    "UpdateReportGroupOutputTypeDef", {"reportGroup": "ReportGroupTypeDef"}, total=False
 )
 
 UpdateWebhookOutputTypeDef = TypedDict(
-    "UpdateWebhookOutputTypeDef", {"webhook": WebhookTypeDef}, total=False
+    "UpdateWebhookOutputTypeDef", {"webhook": "WebhookTypeDef"}, total=False
 )
